@@ -14,7 +14,7 @@ import argparse
 from waitress import serve
 
 from transactions.send_the_coin import send_the_coin
-from transactions.save_to_my_transaction import GetMyTransaction
+from transactions.get_my_transaction import GetMyTransaction
 
 from lib.export import export_the_transactions
 from lib.settings_system import the_settings, test_mode, debug_mode
@@ -160,6 +160,10 @@ def status_page():
 
 
 def start():
+    """
+    Start the API server.
+    """
+
     parser = argparse.ArgumentParser(
         description="This is an open source decentralized application network. In this network, you can develop and publish decentralized applications."
     )
