@@ -20,8 +20,8 @@ from transactions.pending_to_validating import PendinttoValidating
 from transactions.save_to_my_transaction import SavetoMyTransaction
 
 from accounts.account import Account
+from accounts.get_accounts import GetAccounts
 from accounts.save_accounts import save_accounts
-from accounts.save_accounts_part import save_accounts_part
 
 from blockchain.block.save_block_to_blockchain_db import saveBlockstoBlockchainDB
 from blockchain.block.blocks_hash import SaveBlockshash, GetBlockshash, SaveBlockshash_part
@@ -50,7 +50,7 @@ class Block:
     own all the coins.
     """
 
-    def __init__(self, creator):
+    def __init__(self, creator, previous_hash = "0"):
         self.genesis_time = int(time.time())
         self.start_time = int(time.time())
         self.block_time = 7
@@ -59,19 +59,20 @@ class Block:
 
         self.newly = False 
 
-        self.previous_hash = "0"
+        self.previous_hash = previous_hash
         self.sequance_number = 0
         self.empty_block_number = 0
 
         blocks_hash = [self.previous_hash]
         SaveBlockshash(blocks_hash)
-        SaveBlockshash_part([])
 
-        accounts = [
-            Account(creator, balance=1000000000)
-            ]
-        save_accounts(accounts)
-        save_accounts_part([])
+
+        accounts_list = GetAccounts()
+        if accounts_list == []:
+            save_accounts([Account(creator, 1000000000)])
+
+
+
         self.edited_accounts = []
 
         self.pendingTransaction = []
